searchNodes=[{"doc":"Soyaki is a thin abstraction over erlang's :gen_udp sockets, providing the notion of sessions. Semantics heavily inspired by ThousandIsland . Soyaki is implemented as a supervision tree, but currently uses named processes, so you could only run one instance. Applications interact with the sockets primarily through the Soyaki.Handler behavior. Handlers The Soyaki.Handler behavior exists to pass sockets up to the application level. Internally, it's a GenServer whose state tuple consists of {socket, state} (Just a bit of info for anyone who wants to add on to handle_info callbacks). Handlers link to the socket on initialization. Here is an example handler that inspects an incoming packet. defmodule Echo do use Soyaki.Handler @impl Soyaki.Handler def handle_packet ( packet , socket , state ) do IO . inspect ( packet ) { :continue , state } end end { :ok , pid } = Soyaki . start_link ( port : 1234 , handler_module : Echo ) For more information, including other callbacks, please consult the Soyaki.Handler documentation. Starting a Soyaki Server A typical use of Soyaki might look like the following: defmodule MyApp.Supervisor do # ... other Supervisor boilerplate def init ( config ) do children = [ # ... other children as dictated by your app { Soyaki , port : 1234 , handler_module : MyApp.ConnectionHandler } ] Supervisor . init ( children , strategy : :one_for_one ) end end Shutdowns and Crashes Shutdowns are probably fine. For crashes, sockets trap exits and gracefully shut down when they get exit signals from linked processes. Soyaki.Handler doesn't do that by default, but here's an example of a handle_info callback that implements this: @impl Soyaki , Handler def handle_info ( { :EXIT , socket_pid , reason } , { % Socket { socket_pid : socket_pid } , _ } = state_tuple ) do { :stop , reason , state_tuple } end Internals &amp; Sockets Soyaki keeps a registry mapping {host_addr, port} tuples to socket pids. It routes packets arriving in the :gen_udp socket to its own sockets, which are asynchronously listened to by the handlers. A &quot;connection&quot; occurs when a packet arrives from an address that the registry doesn't have a socket for. Scaling &amp; Stress Testing TBD","ref":"Soyaki.html","title":"Soyaki","type":"module"},{"doc":"","ref":"Soyaki.html#child_spec/1","title":"Soyaki.child_spec/1","type":"function"},{"doc":"Starts a Soyaki instance with the given options. Returns a pid that can be used to further manipulate the server via other functions defined on this module in the case of success, or an error tuple describing the reason the server was unable to start in the case of failure.","ref":"Soyaki.html#start_link/1","title":"Soyaki.start_link/1","type":"function"},{"doc":"Synchronously stops the given server, waiting up to the given number of milliseconds for existing connections to finish up. Immediately upon calling this function, the server stops listening for new connections, and then proceeds to wait until either all existing connections have completed or the specified timeout has elapsed.","ref":"Soyaki.html#stop/2","title":"Soyaki.stop/2","type":"function"},{"doc":"","ref":"Soyaki.html#t:options/0","title":"Soyaki.options/0","type":"type"},{"doc":"","ref":"Soyaki.Handler.html","title":"Soyaki.Handler","type":"behaviour"},{"doc":"Called when shutting down the genserver with a reason, usually :local_closed from returning a {:close, state} continuation. Automatically closes the socket.","ref":"Soyaki.Handler.html#c:handle_close/2","title":"Soyaki.Handler.handle_close/2","type":"callback"},{"doc":"Accepts a connection. Doesn't grab the first packet, returns handler_result","ref":"Soyaki.Handler.html#c:handle_connection/2","title":"Soyaki.Handler.handle_connection/2","type":"callback"},{"doc":"Called when shut down for any other reason. Automatically closes the socket.","ref":"Soyaki.Handler.html#c:handle_error/3","title":"Soyaki.Handler.handle_error/3","type":"callback"},{"doc":"Called after the connection was accepted, returns handler_result","ref":"Soyaki.Handler.html#c:handle_packet/3","title":"Soyaki.Handler.handle_packet/3","type":"callback"},{"doc":"Called when straight up shutting down a genserver ( :shutdown ) in terminate callback. Doesn't automatically close the socket.","ref":"Soyaki.Handler.html#c:handle_shutdown/2","title":"Soyaki.Handler.handle_shutdown/2","type":"callback"},{"doc":"Called when terminating due to :timeout . Automatically closes the socket.","ref":"Soyaki.Handler.html#c:handle_timeout/2","title":"Soyaki.Handler.handle_timeout/2","type":"callback"},{"doc":"Called during init , returns state.","ref":"Soyaki.Handler.html#c:init_state/2","title":"Soyaki.Handler.init_state/2","type":"callback"},{"doc":"{:continue, state :: term()} subscribes with the socket's read_timeout, which defaults at 5000ms. {:continue, state :: term(), timeout()} subscribes with given timeout. {:close, state} calls handle_close/2 . {:error, err, state} calls handle_error/3 . Timeouts callback handle_timeout/2","ref":"Soyaki.Handler.html#t:handler_result/0","title":"Soyaki.Handler.handler_result/0","type":"type"},{"doc":"A struct that keeps track of options, and the underlying socket pid. Provides functionality to link/unlink, send, receive, and close. Banged versions might be a thing one day.","ref":"Soyaki.Socket.html","title":"Soyaki.Socket","type":"module"},{"doc":"Subscribes the calling process to the next packet to arrive in the socket. Can send one of 3 messages: :timeout { :udp_closed , nil } { :udp , nil , packet }","ref":"Soyaki.Socket.html#async_recv/2","title":"Soyaki.Socket.async_recv/2","type":"function"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Soyaki.Socket.html#child_spec/1","title":"Soyaki.Socket.child_spec/1","type":"function"},{"doc":"Closes the socket. If specified, a final packet would be sent. Bold of you to expect for it to arrive, though.","ref":"Soyaki.Socket.html#close/3","title":"Soyaki.Socket.close/3","type":"function"},{"doc":"Links a socket to the calling process.","ref":"Soyaki.Socket.html#link/1","title":"Soyaki.Socket.link/1","type":"function"},{"doc":"Listens for a packet to arrive in the socket. Blocks the calling process.","ref":"Soyaki.Socket.html#recv/2","title":"Soyaki.Socket.recv/2","type":"function"},{"doc":"Sends a udp packet to the connected ip and port.","ref":"Soyaki.Socket.html#send/2","title":"Soyaki.Socket.send/2","type":"function"},{"doc":"","ref":"Soyaki.Socket.html#start_link/1","title":"Soyaki.Socket.start_link/1","type":"function"},{"doc":"Uninks a socket from the calling process.","ref":"Soyaki.Socket.html#unlink/1","title":"Soyaki.Socket.unlink/1","type":"function"},{"doc":"","ref":"Soyaki.Socket.html#t:options/0","title":"Soyaki.Socket.options/0","type":"type"},{"doc":"A reference to a socket along with some info.","ref":"Soyaki.Socket.html#t:t/0","title":"Soyaki.Socket.t/0","type":"type"},{"doc":"The state struct for the socket GenServer","ref":"Soyaki.Socket.State.html","title":"Soyaki.Socket.State","type":"module"},{"doc":"","ref":"Soyaki.Socket.State.html#t:t/0","title":"Soyaki.Socket.State.t/0","type":"type"}]